<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>AboutPreferences</name>
    <message>
        <location filename="../src/ui/qml/AboutPreferences.qml" line="14"/>
        <source>Ricochet %1</source>
        <extracomment>%1 version, e.g. 1.0.0</extracomment>
        <translation>Ricochet %1</translation>
    </message>
</context>
<context>
    <name>AddContactDialog</name>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="51"/>
        <source>Share your Ricochet ID to allow connection requests</source>
        <translation>Za povezavo z drugimi posredujte svoj Ricochet ID.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="107"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="112"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
</context>
<context>
    <name>ContactActions</name>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="40"/>
        <source>Open Window</source>
        <translation>Odpri Okno</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="44"/>
        <source>Details...</source>
        <translation>Podrobnosti...</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="48"/>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="53"/>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
</context>
<context>
    <name>ContactIDField</name>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="41"/>
        <source>&lt;b&gt;%1&lt;/b&gt; is already your contact</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; je že med stiki</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="43"/>
        <source>You can&apos;t add yourself as a contact</source>
        <translation>Sebe ne moreš dodati med stike</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="45"/>
        <source>Enter an ID starting with &lt;b&gt;ricochet:&lt;/b&gt;</source>
        <translation>Vnesi ID,  tako da začneš vnos z &lt;b&gt;ricochet:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="81"/>
        <source>Copied to clipboard</source>
        <translation>Kopirano v odložišče</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="93"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
</context>
<context>
    <name>ContactList</name>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="76"/>
        <source>Online</source>
        <translation>Povezan</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="77"/>
        <source>Offline</source>
        <translation>Brez povezave</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="78"/>
        <source>Requests</source>
        <translation>Zahteve</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="79"/>
        <source>Rejected</source>
        <translation>Zavrnjeno</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="80"/>
        <source>Outdated</source>
        <translation>Zastarelo</translation>
    </message>
</context>
<context>
    <name>ContactPreferences</name>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="98"/>
        <source>Date added:</source>
        <translation>Dodan datum:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="106"/>
        <source>Last seen:</source>
        <translation>Nazadnje viden:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="116"/>
        <source>Request:</source>
        <translation>Zahteva:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="126"/>
        <source>Pending connection</source>
        <translation>Povezovanje je v teku</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="127"/>
        <source>Delivered</source>
        <translation>Dostavljeno</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="128"/>
        <source>Accepted</source>
        <translation>Sprejeto</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="129"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="130"/>
        <source>Rejected</source>
        <translation>Zavrnjeno</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="134"/>
        <source>%1 (Connected)</source>
        <extracomment>%1 status, e.g. &quot;Accepted&quot;</extracomment>
        <translation>%1 (Povezan)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="140"/>
        <source>Response:</source>
        <translation>Odgovor:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="163"/>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="170"/>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
</context>
<context>
    <name>ContactRequestDialog</name>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="55"/>
        <source>Someone new is asking to connect to you</source>
        <translation>Nekdo nov se želi povezati z vami</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="102"/>
        <source>Reject</source>
        <translation>Zavrni</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="107"/>
        <source>Accept</source>
        <translation>Sprejmi</translation>
    </message>
</context>
<context>
    <name>ContactRequestFields</name>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="17"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="29"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="40"/>
        <source>Message:</source>
        <translation>Sporočilo:</translation>
    </message>
</context>
<context>
    <name>GeneralPreferences</name>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="13"/>
        <source>Use a single window for conversations</source>
        <translation>Uporabljaj enotno okno za pogovore</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="21"/>
        <source>Open links in default browser without prompting</source>
        <translation>Brez spraševanja odpri povezave v privzetem brskalniku</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="29"/>
        <source>Play audio notifications</source>
        <translation>Predvajaj zvočna obvestila   </translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="38"/>
        <source>Volume</source>
        <translation>Glasnost</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="53"/>
        <source>Language</source>
        <translation type="unfinished">Jezik</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="76"/>
        <source>Restart Ricochet to apply changes</source>
        <translation type="unfinished">Za uveljavitev sprememb ponovno zaženite Ricochet</translation>
    </message>
</context>
<context>
    <name>LanguagePreferences</name>
    <message>
        <source>Select Language</source>
        <translation type="vanished">Izberi jezik</translation>
    </message>
    <message>
        <source>Restart Ricochet to apply changes</source>
        <translation type="vanished">Za uveljavitev sprememb ponovno zaženite Ricochet</translation>
    </message>
</context>
<context>
    <name>LanguagesModel</name>
    <message>
        <location filename="../src/ui/LanguagesModel.cpp" line="43"/>
        <source>System default</source>
        <translation>Sistemsko privzeto</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <source>Ricochet Error</source>
        <translation>Napaka Ricochet</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="19"/>
        <source>Add Contact</source>
        <translation>Dodaj stik</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="28"/>
        <source>Preferences</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="75"/>
        <source>Click to add contacts</source>
        <translation>Klikni za dodajanje kontaktov</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/ui/MainWindow.cpp" line="191"/>
        <source>Remove %1</source>
        <translation>Odstrani  %1</translation>
    </message>
    <message>
        <location filename="../src/ui/MainWindow.cpp" line="192"/>
        <source>Do you want to permanently remove %1?</source>
        <translation>Ali želte za vselej odstraniti %1?</translation>
    </message>
</context>
<context>
    <name>MessageDelegate</name>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="26"/>
        <source>%1 is offline</source>
        <extracomment>%1 nickname</extracomment>
        <translation>%1 ni povezan</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="135"/>
        <source>Copy ID</source>
        <translation>Kopiraj ID</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="135"/>
        <source>Copy Link</source>
        <translation>Kopiraj povezavo</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="140"/>
        <source>Open with Browser</source>
        <translation>Odpri z brskalnikom</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="154"/>
        <source>Add as Contact</source>
        <translation>Dodaj kot stik</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="166"/>
        <source>Copy Message</source>
        <translation>Kopiraj sporočilo</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="173"/>
        <source>Copy Selection</source>
        <translation>Kopiraj izbor</translation>
    </message>
</context>
<context>
    <name>MessageDialogWrapper</name>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="8"/>
        <source>Remove %1</source>
        <translation>Odstrani %1</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="10"/>
        <source>Do you want to permanently remove %1?</source>
        <extracomment>%1 nickname</extracomment>
        <translation>Ali želte za vselej odstraniti %1?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="11"/>
        <source>This contact will no longer be able to message you, and will be notified about the removal. They may choose to send a new connection request.</source>
        <translation>Ta oseba vam ne bo mogla več pošiljati sporočil in bo obveščena o odstranitvi z vašega seznama. Lahko vam pošlje novo zahtevo za povezavo.</translation>
    </message>
</context>
<context>
    <name>NetworkSetupWizard</name>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="100"/>
        <source>This computer&apos;s Internet connection is free of obstacles. I would like to connect directly to the Tor network.</source>
        <translation>Povezava tega računalnika z medmrežjem je brez ovir. Želim se neposredno povezati z omrežjem Tor.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="107"/>
        <source>Connect</source>
        <translation>Poveži se</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="124"/>
        <source>This computer&apos;s Internet connection is censored, filtered, or proxied. I need to configure network settings.</source>
        <translation>Povezava tega računalnika z medmrežjem je cenzurirana, filtrirana ali preusmerjena. Potrebne so ročne nastavitve.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="131"/>
        <source>Configure</source>
        <translation>Nastavi</translation>
    </message>
</context>
<context>
    <name>OfflineStateItem</name>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="107"/>
        <source>Configure</source>
        <translation>Nastavi</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="115"/>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="143"/>
        <source>Connection failed</source>
        <translation>Povezovanje ni uspelo</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="169"/>
        <source>Connecting…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Povezujem...</translation>
    </message>
</context>
<context>
    <name>OpenBrowserDialog</name>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="40"/>
        <source>&lt;b&gt;Warning!&lt;/b&gt; Opening links with your default browser will harm your security and anonymity.&lt;br&gt;&lt;br&gt;You can &lt;a href=&apos;.&apos;&gt;copy to the clipboard&lt;/a&gt; instead.</source>
        <translation>&lt;b&gt;Pozor!&lt;/b&gt; Odpiranje povezav s privzetim brskalnikom škoduje vaši zasebnosti in varnosti.&lt;br&gt;&lt;br&gt;Lahko pa jih namesto tega&lt;a href=&apos;.&apos;&gt;prekopirate v odložišče&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="59"/>
        <source>Don&apos;t ask again for links from %1</source>
        <translation>Ne sprašuj več za povezavo z %1</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="65"/>
        <source>Don&apos;t ask again for any links (not recommended!)</source>
        <translation>Ne sprašuj več za nobeno povezavo (ni priporočljivo!)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="72"/>
        <source>Open Browser</source>
        <translation>Odpri brskalnik</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="84"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="12"/>
        <source>Ricochet Preferences</source>
        <translation>Nastavitve Ricochet</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="41"/>
        <source>General</source>
        <translation>Splošno</translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="vanished">Jezik</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="46"/>
        <source>Contacts</source>
        <translation>Stiki</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="51"/>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="56"/>
        <source>About</source>
        <translation>Več o</translation>
    </message>
</context>
<context>
    <name>QCocoaMenuItem</name>
    <message>
        <location filename="../src/ui/qml/MainWindow.qml" line="29"/>
        <source>Preference</source>
        <translation>Izbira</translation>
    </message>
</context>
<context>
    <name>StartupStatusPage</name>
    <message>
        <location filename="../src/ui/qml/StartupStatusPage.qml" line="18"/>
        <source>The Tor process was not started successfully. This is most likely an installation or system error.</source>
        <translation>Proces Tor se ni uspel uspešno zagnati. Najverjetneje gre za problem pri instalaciji ali sistemsko napako.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/StartupStatusPage.qml" line="49"/>
        <source>Quit</source>
        <translation>Končaj</translation>
    </message>
</context>
<context>
    <name>TorBootstrapStatus</name>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="17"/>
        <source>Connecting to the Tor network…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Povezujem se z omrežjem Tor...</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="51"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="58"/>
        <source>Hide details</source>
        <translation>Skrij podrobnosti</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="58"/>
        <source>Show details</source>
        <translation>Prikaži podrobnosti</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="70"/>
        <source>Done</source>
        <translation>Izvršeno</translation>
    </message>
</context>
<context>
    <name>TorConfigurationPage</name>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="73"/>
        <source>Does this computer need a proxy to access the internet?</source>
        <translation>Potrebuje ta računalnik proksi za dostop do medmrežja?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="85"/>
        <source>Proxy type:</source>
        <translation>Vrsta proksija:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="90"/>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="92"/>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="107"/>
        <source>Address:</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="116"/>
        <source>IP address or hostname</source>
        <translation>Naslov IP ali ime gostitelja</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="119"/>
        <source>Port:</source>
        <translation>Vrata:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="130"/>
        <source>Username:</source>
        <translation>Uporabniško ime:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="140"/>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="150"/>
        <source>Optional</source>
        <translation>Izbirno</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="143"/>
        <source>Password:</source>
        <translation>Geslo:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="160"/>
        <source>Does this computer&apos;s Internet connection go through a firewall that only allows connections to certain ports?</source>
        <translation>Ali poteka povezava tega računalnika z medmrežjem čez požarni zid, ki dovoljuje povezavo le skozi določena vrata?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="171"/>
        <source>Allowed ports:</source>
        <translation>Dovoljena vrata:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="178"/>
        <source>Example: 80,443</source>
        <translation>Primer: 80,443</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="189"/>
        <source>If this computer&apos;s Internet connection is censored, you will need to obtain and use bridge relays.</source>
        <translation>Če je povezava tega računalnika z medmrežjem cenzurirana, morate pridobiti posredniške mostove - bridge relays.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="198"/>
        <source>Enter one or more bridge relays (one per line):</source>
        <translation>Vnesite enega ali več posredniških mostov (enega na vrstico):</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="213"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="220"/>
        <source>Connect</source>
        <translation>Poveži se</translation>
    </message>
</context>
<context>
    <name>TorPreferences</name>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="25"/>
        <source>Running:</source>
        <translation>Teče:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="28"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="30"/>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="28"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="30"/>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <source>External</source>
        <translation>Zunanje</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="27"/>
        <source>Control connected:</source>
        <translation>Nadzorno povezan:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="29"/>
        <source>Circuits established:</source>
        <translation>Vzpostavljen krog:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="31"/>
        <source>Hidden service:</source>
        <translation>Skrite storitve:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="32"/>
        <source>Online</source>
        <translation>Povezan</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="32"/>
        <source>Offline</source>
        <translation>Brez povezave</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="33"/>
        <source>Version:</source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="60"/>
        <source>Error: &lt;b&gt;%1&lt;/b&gt;</source>
        <extracomment>%1 is error message</extracomment>
        <translation>Napaka: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="76"/>
        <source>Configure</source>
        <translation>Nastavi</translation>
    </message>
</context>
<context>
    <name>TorStateWidget</name>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="9"/>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="20"/>
        <source>Connection failed</source>
        <translation>Povezava ni uspela</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="12"/>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="22"/>
        <source>Connecting…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Povezujem...</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="25"/>
        <source>Connecting… (%1%)</source>
        <extracomment>%1 is progress percentage, e.g. 100</extracomment>
        <translation>Povezujem… (%1%)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="32"/>
        <source>Online</source>
        <translation>Povezan</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="34"/>
        <source>Connected</source>
        <translation>Povezan</translation>
    </message>
</context>
</TS>
